API documentation
=================

This documentation is based on the source code of version |release| of the
`chat-archive` package. The following modules are available:

.. contents::
   :local:

:mod:`chat_archive`
-------------------

.. automodule:: chat_archive
   :members:

:mod:`chat_archive.backends`
----------------------------

.. automodule:: chat_archive.backends
   :members:

:mod:`chat_archive.backends.gtalk`
----------------------------------

.. automodule:: chat_archive.backends.gtalk
   :members:

:mod:`chat_archive.backends.hangouts`
-------------------------------------

.. automodule:: chat_archive.backends.hangouts
   :members:

:mod:`chat_archive.backends.slack`
----------------------------------

.. automodule:: chat_archive.backends.slack
   :members:

:mod:`chat_archive.backends.telegram`
-------------------------------------

.. automodule:: chat_archive.backends.telegram
   :members:

:mod:`chat_archive.cli`
-----------------------

.. automodule:: chat_archive.cli
   :members:

:mod:`chat_archive.database`
----------------------------

.. automodule:: chat_archive.database
   :members:

:mod:`chat_archive.emoji`
-------------------------

.. automodule:: chat_archive.emoji
   :members:

:mod:`chat_archive.html`
------------------------

.. automodule:: chat_archive.html
   :members:

:mod:`chat_archive.html.keywords`
---------------------------------

.. automodule:: chat_archive.html.keywords
   :members:

:mod:`chat_archive.html.redirects`
----------------------------------

.. automodule:: chat_archive.html.redirects
   :members:

:mod:`chat_archive.models`
--------------------------

.. automodule:: chat_archive.models
   :members:

:mod:`chat_archive.profiling`
-----------------------------

.. automodule:: chat_archive.profiling
   :members:

:mod:`chat_archive.utils`
-------------------------

.. automodule:: chat_archive.utils
   :members:
